@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 use parent 'Module::Build';
 use Ado::Build qw(
-  process_etc_files process_public_files
+  process_etc_files process_public_files do_create_readme
   process_templates_files create_build_script
   ACTION_perltidy ACTION_submit PERL_DIRS);
 
