@@ -64,7 +64,8 @@ sub run {
     }
 
     # Test
-    $self->render_to_rel_file('test', "$dir/t/plugin/$decamelized-00.t", $class, $$args{name});
+    $self->render_to_rel_file('test', "$dir/t/plugin/$decamelized-00.t",
+        $class, $$args{name}, $decamelized);
 
     # Build.PL
     $self->render_to_rel_file('build_file', "$dir/Build.PL", $class, $path, $dir);
@@ -281,12 +282,14 @@ See http://opensource.org/licenses/lgpl-3.0.html for more information.
 <% %>=cut
 
 @@ test
-% my ($class, $name) = @_;
+% my ($class, $name, $decamelized) = @_;
 use Mojo::Base -strict;
 use Test::More;
 use Test::Mojo;
 
 my $t = Test::Mojo->new('Ado');
+my $app = $t->app;
+ok($app->plugin('<%= $decamelized %>'),'<%= $decamelized %> plugin loaded.');
 
 my $class = '<%= $class %>';
 isa_ok($class, 'Ado::Plugin');
@@ -311,7 +314,8 @@ my $builder = Ado::BuildPlugin->new(
     create_readme      => 1,
     dist_author        => q{Your Name <you@cpan.org>},
     release_status     => 'unstable',
-    build_requires     => {'Test::More' => 0,},
+    configure_requires   => {'Module::Build' => 0.42, Ado => 0},
+    build_requires       => {'Test::More' => 0},
     requires           => {Ado => '<%= Ado->VERSION %>',},
     add_to_cleanup     => ['<%= $dir %>-*', '*.bak'],
 );
